"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.cancelDeleteModel = void 0;
var _constants = require("../constants");
var _error = require("@webiny/error");
var _status = require("./status");
var _store = require("../helpers/store");
const cancelDeleteModel = async params => {
  const {
    context,
    modelId
  } = params;
  const model = await context.cms.getModel(modelId);
  await context.cms.accessControl.ensureCanAccessModel({
    model,
    rwd: "d"
  });
  await context.cms.accessControl.ensureCanAccessEntry({
    model,
    rwd: "w"
  });
  const storeKey = (0, _store.createStoreKey)(model);
  const result = await context.db.store.getValue(storeKey);
  const taskId = result.data?.task;
  await context.db.store.removeValue(storeKey);
  if (!taskId) {
    if (result.error) {
      throw _error.WebinyError.from(result.error, {
        code: "DELETE_MODEL_NO_TASK_DEFINED"
      });
    }
    throw new _error.WebinyError({
      message: `Model "${modelId}" is not being deleted.`,
      code: "MODEL_NOT_BEING_DELETED"
    });
  }
  const task = await context.tasks.getTask(taskId);
  if (task?.definitionId !== _constants.DELETE_MODEL_TASK) {
    throw new _error.WebinyError({
      message: `The task which is deleting a model cannot be found. Please check Step Functions for more info. Task id: ${taskId}`,
      code: "DELETE_MODEL_TASK_NOT_FOUND",
      data: {
        model: model.modelId,
        task: taskId
      }
    });
  }
  const canceledTask = await context.tasks.abort({
    id: task.id,
    message: "User canceled the task."
  });
  return {
    id: canceledTask.id,
    status: (0, _status.getStatus)(canceledTask.taskStatus),
    total: canceledTask.output?.total || 0,
    deleted: canceledTask.output?.deleted || 0
  };
};
exports.cancelDeleteModel = cancelDeleteModel;

//# sourceMappingURL=cancelDeleteModel.js.map